<?php

namespace Drupal\video_embed_champds\Plugin\video_embed_field\Provider;

use Drupal\video_embed_field\ProviderPluginBase;

/**
 * Provides a video embed provider for ChampDS videos.
 *
 * @VideoEmbedProvider(
 *   id = "champds",
 *   title = @Translation("ChampDS")
 * )
 */
class ChampDS extends ProviderPluginBase {
  /**
   * Helper function to extract the domain and base path without video ID.
   *
   * @param string $input
   *   Full input URL.
   *
   * @return string
   *   Path without the video ID (e.g., play.champds.com/account/live).
   */
  protected function getPathFromInput($input): string {
    $parsed = parse_url($input);

    $host = $parsed['host'] ?? 'play.champds.com';
    $path = trim($parsed['path'] ?? '', '/');

    // Remove trailing /s/{number} if present.
    $path = preg_replace('/\/(s|t)\/\d+$/', '', $path);

    // Remove the last numeric segment (video ID).
    $segments = explode('/', $path);
    if (is_numeric(end($segments))) {
      array_pop($segments);
    }

    return $host . '/' . implode('/', $segments);
  }

  /**
   * {@inheritdoc}
   */
  public function getRemoteThumbnailUrl() {
    // ChampDS does not expose thumbnail images publicly.
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public static function getIdFromInput($input): false|string {
    // Match URLs with /event/123, /live/123, or /embed/123 format
    // with optional segments like /s/8 after the ID.
    if (preg_match('#/(event|embed|live)/(\d+)(?:/.*)?$#', $input, $matches)) {
      return $matches[2];
    }

    // Fallback: match last numeric segment.
    if (preg_match('#/(\d+)(?:/.*)?$#', $input, $matches)) {
      return $matches[1];
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function renderEmbedCode($width, $height, $autoplay) {
    $path = $this->getPathFromInput($this->input);
    $video_id = $this->getVideoId();

    return [
      '#type' => 'video_embed_iframe',
      '#provider' => 'champds',
      '#url' => sprintf('https://%s/%s', $path, $video_id),
      '#query' => [
        'autoPlay' => $autoplay ? '1' : '0',
      ],
      '#attributes' => [
        'width' => $width,
        'height' => $height,
        'frameborder' => '0',
        'allowfullscreen' => 'allowfullscreen',
      ],
    ];
  }

}
